function round(number, zeroes)
	local zeroes = zeroes or 0
	return math.floor(number * (10 ^ zeroes) + .5) / (10 ^ zeroes)
end

-------------------------------------------------------------------------------
function RatingsToPercent(RperL, K, Xo, Yo)
	return Yo + 1 / (1 + K / (RperL - Xo))
end

-------------------------------------------------------------------------------
-- Physical Mitigation
-- Tactical Mitigation
function Mitigation(R, L)
	local percent

	if MyClass == Turbine.Gameplay.Class.LoreMaster or
	MyClass == Turbine.Gameplay.Class.Minstrel or
	MyClass == Turbine.Gameplay.Class.RuneKeeper then

		-- break: 20% @ 37.5 R/L
		if (R / L) > 37.5 then
			percent = RatingsToPercent(R / L, 350, 37.5, 0.2)
		else
			percent = RatingsToPercent(R / L, 150, 0, 0)
		end
		-- maximum: 40% @ 125 R/L
		return math.min(0.4, percent)

	elseif MyClass == Turbine.Gameplay.Class.Burglar or
	MyClass == Turbine.Gameplay.Class.Hunter or
	MyClass == Turbine.Gameplay.Class.Warden then

		-- break: 20% @ 37.5 R/L
		if (R / L) > 37.5 then
			percent = RatingsToPercent(R / L, 350, 37.5, 0.2)
		else
			percent = RatingsToPercent(R / L, 150, 0, 0)
		end
		-- maximum: 50% @ 187.5 R/L
		return math.min(0.5, percent)

	elseif MyClass == Turbine.Gameplay.Class.Captain or
	MyClass == Turbine.Gameplay.Class.Champion or
	MyClass == Turbine.Gameplay.Class.Guardian then

		-- break: 10% @ 50/3 R/L
		if (R / L) > (50 / 3) then
			percent = RatingsToPercent(R / L, 150, 50 / 3, 0.1)
		else
			percent = RatingsToPercent(R / L, 150, 0, 0)
		end
		-- maximum: 70% @ 725/3 R/L
		return math.min(0.7, percent)

	else  -- Session Play uses the same formulae as Heavy Mitigation (I think)

		-- break: 10% @ 50/3 R/L
		if (R / L) > (50 / 3) then
			percent = RatingsToPercent(R / L, 150, 50 / 3, 0.1)
		else
			percent = RatingsToPercent(R / L, 150, 0, 0)
		end
		-- maximum: 70% @ 725/3 R/L
		return math.min(0.7, percent)

	end
end

-- Physical Offence
-- Ranged Offence
-- Tactical Offence
function Offence(R, L)
	local segment, remainder = math.modf((R - 1) / L / 75)

	local percent = RatingsToPercent(R / L, 300, segment * 75, segment / 5)

	-- no maximum
	return percent
end

-- Critical Hit
-- Incoming Healing
-- Block
-- Parry
-- Evade
-- Melee Defence
-- Ranged Defence
-- Tactical Defence
function Avoidance(R, L)
	local percent
	-- break: 15% @ 70 R/L
	if (R / L) > 70 then
		percent = RatingsToPercent(R / L, 2380 / 3, 70, 0.15)
	else
		percent = RatingsToPercent(R / L, 1190 / 3, 0, 0)
	end
	-- maximum: 25% @ 4270/27 R/L

	return math.min(0.25, percent)
end

-- Devastating Hit
-- Devastate Defence
-- Partial Block
-- Partial Parry
-- Partial Evade
function PartialAvoidance(R, L)
	local percent
	percent = RatingsToPercent(R / L, 1330, 0, 0)
	-- maximum: 10% @ 1330/9 R/L
	return math.min(0.1, percent)
end

-- Finesse
-- Resistance
-- Outgoing Healing
function Resistance(R, L)
	local percent
	-- break: 30% @ 170 R/L
	if (R / L) > 170 then
		percent = RatingsToPercent(R / L, 2380 / 3, 170, 0.3)
	else
		percent = RatingsToPercent(R / L, 1190 / 3, 0, 0)
	end
	-- maximum: 50% @ 1105/3 R/L
	return math.min(0.5, percent)
end

-- Critical Defence
function CriticalDefence(R, L)
	local percent
	percent = RatingsToPercent(R / L, 100, 0, 0)
	-- maximum: FIXME
--	return math.min(1, percent)
	return percent
end

-- Critical Magnitude
function CriticalMagnitude(R, L)
	local percent
	percent = RatingsToPercent(R / L, 300, 0, 0)
	-- maximum: FIXME
--	return math.min(1, percent)
	return percent
end